@@ -445,10 +445,9 @@ class DeviceManager extends InterProcessData {
 	 * Amount of items to me synchronized.
 	 *
 	 * @param string $folderid
-	 * @param string $type
-	 * @param int    $queuedmessages;
 	 * @param mixed  $uuid
 	 * @param mixed  $statecounter
+	 * @param mixed  $queuedmessages
 	 *
 	 * @return int
 	 */
@@ -476,7 +475,7 @@ class DeviceManager extends InterProcessData {
 		}
 
 		if ($items >= 0 && $items <= 2) {
-			SLog::Write(LOGLEVEL_WARN, sprintf("Mobile loop detected! Messages sent to the mobile will be restricted to %d items in order to identify the conflict", $items));
+			SLog::Write(LOGLEVEL_INFO, sprintf("Mobile loop detected! Messages sent to the mobile will be restricted to %d items in order to identify the conflict", $items));
 		}
 
 		return $items;
