@@ -2,7 +2,7 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2022 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  *
  * Provides the SYNC command
  */
@@ -61,7 +61,7 @@ class Sync extends RequestProcessor {
 			// Syncing specified folders
 			// Android still sends heartbeat sync even if all syncfolders are disabled.
 			// Check if Folders tag is empty (<Folders/>) and only sync if there are
-			// some folders in the request. See ZP-172
+			// some folders in the request.
 			$startTag = self::$decoder->getElementStartTag(SYNC_FOLDERS);
 			if (isset($startTag[EN_FLAGS]) && $startTag[EN_FLAGS]) {
 				while (self::$decoder->getElementStartTag(SYNC_FOLDER)) {
@@ -183,7 +183,7 @@ class Sync extends RequestProcessor {
 
 					// SUPPORTED properties
 					if (($se = self::$decoder->getElementStartTag(SYNC_SUPPORTED)) !== false) {
-						// ZP-481: LG phones send an empty supported tag, so only read the contents if available here
+						// LG phones send an empty supported tag, so only read the contents if available here
 						// if <Supported/> is received, it's as no supported fields would have been sent at all.
 						// unsure if this is the correct approach, or if in this case some default list should be used
 						if ($se[EN_FLAGS] & EN_FLAGS_CONTENT) {
@@ -230,7 +230,7 @@ class Sync extends RequestProcessor {
 
 					if (self::$decoder->getElementStartTag(SYNC_WINDOWSIZE)) {
 						$ws = self::$decoder->getElementContent();
-						// normalize windowsize - see ZP-477
+						// normalize windowsize
 						if ($ws == 0 || $ws > WINDOW_SIZE_MAX) {
 							$ws = WINDOW_SIZE_MAX;
 						}
@@ -442,6 +442,12 @@ class Sync extends RequestProcessor {
 						SLog::Write(LOGLEVEL_DEBUG, "HierarchyCache is also not available. Triggering HierarchySync to device");
 					}
 
+					// AS16: Check if this is a DRAFTS folder - if so, disable FilterType
+					if (Request::GetProtocolVersion() >= 16.0 && self::$deviceManager->GetFolderTypeFromCacheById($spa->GetFolderId()) == SYNC_FOLDER_TYPE_DRAFTS) {
+						$spa->SetFilterType(SYNC_FILTERTYPE_DISABLE);
+						SLog::Write(LOGLEVEL_DEBUG, "HandleSync(): FilterType has been disabled as this is a DRAFTS folder.");
+					}
+
 					if (($el = self::$decoder->getElementStartTag(SYNC_PERFORM)) && ($el[EN_FLAGS] & EN_FLAGS_CONTENT)) {
 						// We can not proceed here as the content class is unknown
 						if ($status != SYNC_STATUS_SUCCESS) {
@@ -493,6 +499,15 @@ class Sync extends RequestProcessor {
 									}
 								}
 							}
+							// get the instanceId if available
+							$instanceid = false;
+							if (self::$decoder->getElementStartTag(SYNC_AIRSYNCBASE_INSTANCEID)) {
+								if (($instanceid = self::$decoder->getElementContent()) !== false) {
+									if (!self::$decoder->getElementEndTag()) { // end instanceid
+										return false;
+									}
+								}
+							}
 
 							if (self::$decoder->getElementStartTag(SYNC_CLIENTENTRYID)) {
 								$clientid = self::$decoder->getElementContent();
@@ -521,6 +536,20 @@ class Sync extends RequestProcessor {
 								$message = false;
 							}
 
+							// InstanceID sent: do action to a recurrency exception
+							if ($instanceid) {
+								// for delete actions we don't have an ASObject
+								if (!$message) {
+									$message = GSync::getSyncObjectFromFolderClass($spa->GetContentClass());
+									$message->Decode(self::$decoder);
+								}
+								$message->instanceid = $instanceid;
+								if ($element[EN_TAG] == SYNC_REMOVE) {
+									$message->instanceiddelete = true;
+									$element[EN_TAG] = SYNC_MODIFY;
+								}
+							}
+
 							switch ($element[EN_TAG]) {
 								case SYNC_FETCH:
 									array_push($actiondata["fetchids"], $serverid);
@@ -567,6 +596,13 @@ class Sync extends RequestProcessor {
 							catch (StatusException $stex) {
 								$status = $stex->getCode();
 							}
+
+							// Check if changes are requested - if not and there are no changes to be exported anyway, update folderstat!
+							if (!$sc->GetParameter($spa, "getchanges") && !$sc->CountChange($spa->GetFolderId())) {
+								SLog::Write(LOGLEVEL_DEBUG, "Incoming changes, no export requested: update folderstat");
+								$newFolderStatAfterImport = self::$backend->GetFolderStat(GSync::GetAdditionalSyncFolderStore($spa->GetBackendFolderId()), $spa->GetBackendFolderId());
+								$this->setFolderStat($spa, $newFolderStatAfterImport);
+							}
 						}
 
 						if (!self::$decoder->getElementEndTag()) { // end PERFORM
@@ -699,15 +735,12 @@ class Sync extends RequestProcessor {
 		// HEARTBEAT
 		if ($status == SYNC_STATUS_SUCCESS && isset($hbinterval)) {
 			$interval = (defined('PING_INTERVAL') && PING_INTERVAL > 0) ? PING_INTERVAL : 30;
-
-			if (isset($hbinterval)) {
-				$sc->SetLifetime($hbinterval);
-			}
+			$sc->SetLifetime($hbinterval);
 
 			// states are lazy loaded - we have to make sure that they are there!
 			$loadstatus = SYNC_STATUS_SUCCESS;
 			foreach ($sc as $folderid => $spa) {
-				// some androids do heartbeat on the OUTBOX folder, with weird results - ZP-362
+				// some androids do heartbeat on the OUTBOX folder, with weird results
 				// we do not load the state so we will never get relevant changes on the OUTBOX folder
 				if (self::$deviceManager->GetFolderTypeFromCacheById($folderid) == SYNC_FOLDER_TYPE_OUTBOX) {
 					SLog::Write(LOGLEVEL_DEBUG, sprintf("HandleSync(): Heartbeat on Outbox folder not allowed"));
@@ -826,7 +859,7 @@ class Sync extends RequestProcessor {
 
 			// TODO we could check against $sc->GetChangedFolderIds() on heartbeat so we do not need to configure all exporter again
 			if ($status == SYNC_STATUS_SUCCESS && ($sc->GetParameter($spa, "getchanges") || !$spa->HasSyncKey())) {
-				// no need to run the exporter if the globalwindowsize is already full - if collection already has a synckey (ZP-1215)
+				// no need to run the exporter if the globalwindowsize is already full - if collection already has a synckey
 				if ($sc->GetGlobalWindowSize() == $this->globallyExportedItems && $spa->HasSyncKey()) {
 					SLog::Write(LOGLEVEL_DEBUG, sprintf("Sync(): no exporter setup for '%s' as GlobalWindowSize is full.", $spa->GetFolderId()));
 					$setupExporter = false;
@@ -929,7 +962,7 @@ class Sync extends RequestProcessor {
 			}
 			// get a new synckey only if we did not reach the global limit yet
 			else {
-				// when reaching the global limit for changes of all collections, stop processing other collections (ZP-697)
+				// when reaching the global limit for changes of all collections, stop processing other collections
 				if ($sc->GetGlobalWindowSize() <= $this->globallyExportedItems) {
 					SLog::Write(LOGLEVEL_DEBUG, "Global WindowSize for amount of exported changes reached, omitting output for collection.");
 
@@ -973,7 +1006,7 @@ class Sync extends RequestProcessor {
 			self::$encoder->endTag();
 		}
 
-		// Check if there was any response - in case of an empty sync request, we shouldn't send an empty answer (ZP-1241)
+		// Check if there was any response - in case of an empty sync request, we shouldn't send an empty answer
 		if (!$this->startTagsSent && $emptysync === true) {
 			$this->sendStartTags();
 			self::$encoder->startTag(SYNC_STATUS);
@@ -1031,9 +1064,9 @@ class Sync extends RequestProcessor {
 	 * @param int                 $status         current status of the folder processing
 	 * @param string              $newFolderStat  the new folder stat to be set if everything was exported
 	 *
-	 * @throws StatusException
-	 *
 	 * @return int sync status code
+	 *
+	 * @throws StatusException
 	 */
 	private function syncFolder($sc, $spa, $exporter, $changecount, $streamimporter, $status, $newFolderStat) {
 		$actiondata = $sc->GetParameter($spa, "actiondata");
@@ -1083,25 +1116,30 @@ class Sync extends RequestProcessor {
 		)) {
 			self::$encoder->startTag(SYNC_REPLIES);
 			// output result of all new incoming items
-			foreach ($actiondata["clientids"] as $clientid => $serverid) {
+			foreach ($actiondata["clientids"] as $clientid => $response) {
 				self::$encoder->startTag(SYNC_ADD);
 				self::$encoder->startTag(SYNC_CLIENTENTRYID);
 				self::$encoder->content($clientid);
 				self::$encoder->endTag();
-				if ($serverid) {
+				if (!empty($response->serverid)) {
 					self::$encoder->startTag(SYNC_SERVERENTRYID);
-					self::$encoder->content($serverid);
+					self::$encoder->content($response->serverid);
 					self::$encoder->endTag();
 				}
 				self::$encoder->startTag(SYNC_STATUS);
-				self::$encoder->content((isset($actiondata["statusids"][$clientid]) ? $actiondata["statusids"][$clientid] : SYNC_STATUS_CLIENTSERVERCONVERSATIONERROR));
+				self::$encoder->content(isset($actiondata["statusids"][$clientid]) ? $actiondata["statusids"][$clientid] : SYNC_STATUS_CLIENTSERVERCONVERSATIONERROR);
 				self::$encoder->endTag();
+				if (!empty($response->hasResponse)) {
+					self::$encoder->startTag(SYNC_DATA);
+					$response->Encode(self::$encoder);
+					self::$encoder->endTag();
+				}
 				self::$encoder->endTag();
 			}
 
 			// loop through modify operations which were not a success, send status
-			foreach ($actiondata["modifyids"] as $serverid) {
-				if (isset($actiondata["statusids"][$serverid]) && $actiondata["statusids"][$serverid] !== SYNC_STATUS_SUCCESS) {
+			foreach ($actiondata["modifyids"] as $serverid => $response) {
+				if (isset($actiondata["statusids"][$serverid]) && ($actiondata["statusids"][$serverid] !== SYNC_STATUS_SUCCESS || !empty($response->hasResponse))) {
 					self::$encoder->startTag(SYNC_MODIFY);
 					self::$encoder->startTag(SYNC_SERVERENTRYID);
 					self::$encoder->content($serverid);
@@ -1109,6 +1147,11 @@ class Sync extends RequestProcessor {
 					self::$encoder->startTag(SYNC_STATUS);
 					self::$encoder->content($actiondata["statusids"][$serverid]);
 					self::$encoder->endTag();
+					if (!empty($response->hasResponse)) {
+						self::$encoder->startTag(SYNC_DATA);
+						$response->Encode(self::$encoder);
+						self::$encoder->endTag();
+					}
 					self::$encoder->endTag();
 				}
 			}
@@ -1198,7 +1241,7 @@ class Sync extends RequestProcessor {
 
 		// Stream outgoing changes
 		if ($status == SYNC_STATUS_SUCCESS && $sc->GetParameter($spa, "getchanges") == true && $windowSize > 0 && (bool) $exporter) {
-			self::$topCollector->AnnounceInformation(sprintf("Streaming data of %d objects", (($changecount > $windowSize) ? $windowSize : $changecount)));
+			self::$topCollector->AnnounceInformation(sprintf("Streaming data of %d objects", ($changecount > $windowSize) ? $windowSize : $changecount));
 
 			// Output message changes per folder
 			self::$encoder->startTag(SYNC_PERFORM);
@@ -1213,7 +1256,7 @@ class Sync extends RequestProcessor {
 					}
 					++$n;
 					if ($n % 10 == 0) {
-						self::$topCollector->AnnounceInformation(sprintf("Streamed data of %d objects out of %d", $n, (($changecount > $windowSize) ? $windowSize : $changecount)));
+						self::$topCollector->AnnounceInformation(sprintf("Streamed data of %d objects out of %d", $n, ($changecount > $windowSize) ? $windowSize : $changecount));
 					}
 				}
 				catch (SyncObjectBrokenException $mbe) {
@@ -1232,7 +1275,7 @@ class Sync extends RequestProcessor {
 				// something really bad happened while exporting changes
 				catch (StatusException $stex) {
 					$status = $stex->getCode();
-					// during export we found out that the states should be thrown away (ZP-623)
+					// during export we found out that the states should be thrown away
 					if ($status == SYNC_STATUS_INVALIDSYNCKEY) {
 						self::$deviceManager->ForceFolderResync($spa->GetFolderId());
 
@@ -1280,7 +1323,7 @@ class Sync extends RequestProcessor {
 			if ($changecount === 0 || ($changecount !== false && $changecount <= $windowSize)) {
 				self::$deviceManager->SetFolderSyncStatus($spa->GetFolderId(), DeviceManager::FLD_SYNC_COMPLETED);
 
-				// we should update the folderstat, but we recheck to see if it changed. If so, it's not updated to force another sync
+				// we should update the folderstat, but we recheck to see if it changed since the exporter setup. If so, it's not updated to force another sync
 				if (self::$backend->HasFolderStats()) {
 					$newFolderStatAfterExport = self::$backend->GetFolderStat(GSync::GetAdditionalSyncFolderStore($spa->GetBackendFolderId()), $spa->GetBackendFolderId());
 					if ($newFolderStat === $newFolderStatAfterExport) {
@@ -1303,7 +1346,7 @@ class Sync extends RequestProcessor {
 			self::$topCollector->AnnounceInformation("Saving state");
 
 			try {
-				if (isset($exporter) && $exporter) {
+				if ($exporter) {
 					$state = $exporter->GetState();
 				}
 
@@ -1416,7 +1459,7 @@ class Sync extends RequestProcessor {
 					$this->importer->Config($sc->GetParameter($spa, "state"), $spa->GetConflict());
 				}
 
-				// the CPO is also needed by the importer to check if imported changes are inside the sync window - see ZP-258
+				// the CPO is also needed by the importer to check if imported changes are inside the sync window
 				$this->importer->ConfigContentParameters($spa->GetCPO());
 				$this->importer->LoadConflicts($spa->GetCPO(), $sc->GetParameter($spa, "state"));
 			}
@@ -1441,9 +1484,9 @@ class Sync extends RequestProcessor {
 	 * @param string         $foldertype   On sms sync, this says "SMS", else false
 	 * @param int            $messageCount Counter of already imported messages
 	 *
-	 * @throws StatusException in case the importer is not available
-	 *
 	 * @return - message related status are returned in the actiondata
+	 *
+	 * @throws StatusException in case the importer is not available
 	 */
 	private function importMessage($spa, &$actiondata, $todo, $message, $clientid, $serverid, $foldertype, $messageCount) {
 		// the importer needs to be available!
@@ -1469,7 +1512,7 @@ class Sync extends RequestProcessor {
 				$actiondata["clientids"][$clientid] = $actiondata["failstate"]["clientids"][$clientid];
 				$actiondata["statusids"][$clientid] = $actiondata["failstate"]["statusids"][$clientid];
 
-				SLog::Write(LOGLEVEL_WARN, sprintf("Mobile loop detected! Incoming new message '%s' was created on the server before. Replying with known new server id: %s", $clientid, $actiondata["clientids"][$clientid]));
+				SLog::Write(LOGLEVEL_INFO, sprintf("Mobile loop detected! Incoming new message '%s' was created on the server before. Replying with known new server id: %s", $clientid, $actiondata["clientids"][$clientid]));
 			}
 
 			// message was REMOVED before, do NOT attempt to remove it again
@@ -1482,7 +1525,7 @@ class Sync extends RequestProcessor {
 				$actiondata["removeids"][$serverid] = $actiondata["failstate"]["removeids"][$serverid];
 				$actiondata["statusids"][$serverid] = $actiondata["failstate"]["statusids"][$serverid];
 
-				SLog::Write(LOGLEVEL_WARN, sprintf("Mobile loop detected! Message '%s' was deleted by the mobile before. Replying with known status: %s", $clientid, $actiondata["statusids"][$serverid]));
+				SLog::Write(LOGLEVEL_INFO, sprintf("Mobile loop detected! Message '%s' was deleted by the mobile before. Replying with known status: %s", $clientid, $actiondata["statusids"][$serverid]));
 			}
 		}
 
@@ -1492,8 +1535,6 @@ class Sync extends RequestProcessor {
 					self::$topCollector->AnnounceInformation(sprintf("Saving modified message %d", $messageCount));
 
 					try {
-						$actiondata["modifyids"][] = $serverid;
-
 						// ignore sms messages
 						if ($foldertype == "SMS" || stripos($serverid, self::GSYNCIGNORESMS) !== false) {
 							SLog::Write(LOGLEVEL_DEBUG, "SMS sync are not supported. Ignoring message.");
@@ -1505,20 +1546,16 @@ class Sync extends RequestProcessor {
 							$actiondata["statusids"][$serverid] = SYNC_STATUS_CLIENTSERVERCONVERSATIONERROR;
 						}
 						else {
-							if (isset($message->read)) {
-								// Currently, 'read' is only sent by the PDA when it is ONLY setting the read flag.
-								$this->importer->ImportMessageReadFlag($serverid, $message->read);
+							// if there is just a read flag change, import it via ImportMessageReadFlag()
+							if (isset($message->read) && !isset($message->flag) && $message->getCheckedParameters() < 3) {
+								$response = $this->importer->ImportMessageReadFlag($serverid, $message->read);
 							}
-							elseif (!isset($message->flag)) {
-								$this->importer->ImportMessageChange($serverid, $message);
-							}
-
-							// email todoflags - some devices send todos flags together with read flags,
-							// so they have to be handled separately
-							if (isset($message->flag)) {
-								$this->importer->ImportMessageChange($serverid, $message);
+							else {
+								$response = $this->importer->ImportMessageChange($serverid, $message);
 							}
 
+							$response->serverid = $serverid;
+							$actiondata["modifyids"][$serverid] = $response;
 							$actiondata["statusids"][$serverid] = SYNC_STATUS_SUCCESS;
 						}
 					}
@@ -1604,8 +1641,6 @@ class Sync extends RequestProcessor {
 	 *
 	 * @param mixed $key
 	 * @param mixed $value
-	 *
-	 * @return
 	 */
 	private function saveMultiFolderInfo($key, $value) {
 		if ($key == "incoming" || $key == "outgoing" || $key == "queued" || $key == "fetching") {
@@ -1663,8 +1698,6 @@ class Sync extends RequestProcessor {
 	 *
 	 * @param SyncParameters $spa
 	 * @param string         $newFolderStat
-	 *
-	 * @return
 	 */
 	private function setFolderStat($spa, $newFolderStat) {
 		$spa->SetFolderStat($newFolderStat);
