@@ -197,50 +197,6 @@ class Utils {
 		return null;
 	}
 
-	/**
-	 * Checks if the PHP-MAPI extension is available and in a requested version.
-	 *
-	 * @param string $version the version to be checked ("6.30.10-18495", parts or build number)
-	 *
-	 * @return bool installed version is superior to the checked string
-	 */
-	public static function CheckMapiExtVersion($version = "") {
-		if (!extension_loaded("mapi")) {
-			return false;
-		}
-		// compare build number if requested
-		if (preg_match('/^\d+$/', $version) && strlen($version) > 3) {
-			$vs = preg_split('/-/', phpversion("mapi"));
-
-			return $version <= $vs[1];
-		}
-		if (version_compare(phpversion("mapi"), $version) == -1) {
-			return false;
-		}
-
-		return true;
-	}
-
-	/**
-	 * Parses and returns an ecoded vCal-Uid from an OL compatible GlobalObjectID.
-	 *
-	 * @param string $olUid an OL compatible GlobalObjectID
-	 *
-	 * @return string the vCal-Uid if available in the olUid, else the original olUid as HEX
-	 */
-	public static function GetICalUidFromOLUid($olUid) {
-		// check if "vCal-Uid" is somewhere in outlookid case-insensitive
-		$icalUid = stristr($olUid, "vCal-Uid");
-		if ($icalUid !== false) {
-			// get the length of the ical id - go back 4 position from where "vCal-Uid" was found
-			$begin = unpack("V", substr($olUid, strlen($icalUid) * (-1) - 4, 4));
-			// remove "vCal-Uid" and packed "1" and use the ical id length
-			return substr($icalUid, 12, ($begin[1] - 13));
-		}
-
-		return strtoupper(bin2hex($olUid));
-	}
-
 	/**
 	 * Extracts the basedate of the GlobalObjectID and the RecurStartTime.
 	 *
@@ -433,7 +389,7 @@ class Utils {
 			$foldertype == SYNC_FOLDER_TYPE_CONTACT ||
 			$foldertype == SYNC_FOLDER_TYPE_NOTE ||
 			$foldertype == SYNC_FOLDER_TYPE_JOURNAL
-			) ? true : false;
+		) ? true : false;
 	}
 
 	/**
@@ -506,7 +462,8 @@ class Utils {
 			case GSync::COMMAND_RESOLVERECIPIENTS:    return 'ResolveRecipients';
 
 			case GSync::COMMAND_VALIDATECERT:         return 'ValidateCert';
-			// Deprecated commands
+
+				// Deprecated commands
 			case GSync::COMMAND_GETHIERARCHY:         return 'GetHierarchy';
 
 			case GSync::COMMAND_CREATECOLLECTION:     return 'CreateCollection';
@@ -569,7 +526,8 @@ class Utils {
 			case 'ResolveRecipients':    return GSync::COMMAND_RESOLVERECIPIENTS;
 
 			case 'ValidateCert':         return GSync::COMMAND_VALIDATECERT;
-			// Deprecated commands
+
+				// Deprecated commands
 			case 'GetHierarchy':         return GSync::COMMAND_GETHIERARCHY;
 
 			case 'CreateCollection':     return GSync::COMMAND_CREATECOLLECTION;
@@ -677,6 +635,7 @@ class Utils {
 		if (isset($codepages[$codepage])) {
 			return $codepages[$codepage];
 		}
+
 		// Defaulting to iso-8859-15 since it is more likely for someone to make a mistake in the codepage
 		// when using west-european charsets then when using other charsets since utf-8 is binary compatible
 		// with the bottom 7 bits of west-european
@@ -883,72 +842,99 @@ class Utils {
 	}
 
 	/**
-	 * Converts a string freebusy type into a numeric status.
+	 * Transforms an AS timestamp into a unix timestamp.
 	 *
-	 * @param string $fbType
+	 * @param string $ts
 	 *
-	 * @return int
+	 * @return long
 	 */
-	public static function GetFbStatusFromType($fbType) {
-		switch ($fbType) {
-			case 'Free':
-				return fbFree;
+	public static function ParseDate($ts) {
+		if (preg_match("/(\\d{4})[^0-9]*(\\d{2})[^0-9]*(\\d{2})(T(\\d{2})[^0-9]*(\\d{2})[^0-9]*(\\d{2})(.\\d+)?Z){0,1}$/", $ts, $matches)) {
+			if ($matches[1] >= 2038) {
+				$matches[1] = 2038;
+				$matches[2] = 1;
+				$matches[3] = 18;
+				$matches[5] = $matches[6] = $matches[7] = 0;
+			}
 
-			case 'Tentative':
-				return fbTentative;
+			if (!isset($matches[5])) {
+				$matches[5] = 0;
+			}
+			if (!isset($matches[6])) {
+				$matches[6] = 0;
+			}
+			if (!isset($matches[7])) {
+				$matches[7] = 0;
+			}
 
-			case 'Busy':
-				return fbBusy;
-
-			case 'OOF':
-				return fbOutOfOffice;
+			return gmmktime($matches[5], $matches[6], $matches[7], $matches[2], $matches[3], $matches[1]);
 		}
-		SLog::Write(LOGLEVEL_WARN, sprintf("Utils->GetFbStatusFromType(): Unknown free busy type '%s'", $fbType));
 
-		return fbNoData;
-	}
-}
-
-// TODO Win1252/UTF8 functions are deprecated and will be removed sometime
-// if the ICS backend is loaded in CombinedBackend and Zarafa > 7
-// STORE_SUPPORTS_UNICODE is true and the conversion will not be done
-// for other backends.
-function utf8_to_windows1252($string, $option = "", $force_convert = false) {
-	// if the store supports unicode return the string without converting it
-	if (!$force_convert && defined('STORE_SUPPORTS_UNICODE') && STORE_SUPPORTS_UNICODE === true) {
-		return $string;
+		return 0;
 	}
 
-	if (function_exists("iconv")) {
-		return @iconv("UTF-8", "Windows-1252" . $option, $string);
+	/**
+	 * Transforms an unix timestamp into an AS timestamp or a human readable format.
+	 *
+	 * Oh yeah, this is beautiful. Exchange outputs date fields differently in calendar items
+	 * and emails. We could just always send one or the other, but unfortunately nokia's 'Mail for
+	 * exchange' depends on this quirk. So we have to send a different date type depending on where
+	 * it's used. Sigh.
+	 *
+	 * @param int $ts
+	 * @param int $type int (StreamerType) (optional) if not set a human readable format is returned
+	 *
+	 * @return string
+	 */
+	public static function FormatDate($ts, $type = "") {
+		// fallback to a human readable format (used for logging)
+		$formatString = "yyyy-MM-dd HH:mm:SS' UTC'";
+		if ($type == Streamer::STREAMER_TYPE_DATE) {
+			$formatString = "yyyyMMdd'T'HHmmSS'Z'";
+		}
+		elseif ($type == Streamer::STREAMER_TYPE_DATE_DASHES) {
+			$formatString = "yyyy-MM-dd'T'HH:mm:SS'.000Z'";
+		}
+
+		$formatter = datefmt_create(
+			'en_US',
+			IntlDateFormatter::FULL,
+			IntlDateFormatter::FULL,
+			'UTC',
+			IntlDateFormatter::GREGORIAN,
+			$formatString
+		);
+
+		return datefmt_format($formatter, $ts);
 	}
 
-	return utf8_decode($string); // no euro support here
-}
+	/**
+	 * Returns the appropriate SyncObjectResponse object based on message class.
+	 *
+	 * @param string $messageClass
+	 *
+	 * @return object
+	 */
+	public static function GetResponseFromMessageClass($messageClass) {
+		$messageClass = strtolower($messageClass);
 
-function windows1252_to_utf8($string, $option = "", $force_convert = false) {
-	// if the store supports unicode return the string without converting it
-	if (!$force_convert && defined('STORE_SUPPORTS_UNICODE') && STORE_SUPPORTS_UNICODE === true) {
-		return $string;
+		switch ($messageClass) {
+			case 'syncappointment':
+				return new SyncAppointmentResponse();
+
+			case 'synccontact':
+				return new SyncContactResponse();
+
+			case 'syncnote':
+				return new SyncNoteResponse();
+
+			case 'synctask':
+				return new SyncTaskResponse();
+
+			default:
+				return new SyncMailResponse();
+		}
+
+		return new SyncMailResponse();
 	}
-
-	if (function_exists("iconv")) {
-		return @iconv("Windows-1252", "UTF-8" . $option, $string);
-	}
-
-	return utf8_encode($string); // no euro support here
-}
-
-function w2u($string) {
-	return windows1252_to_utf8($string);
-}
-function u2w($string) {
-	return utf8_to_windows1252($string);
-}
-
-function w2ui($string) {
-	return windows1252_to_utf8($string, "//TRANSLIT");
-}
-function u2wi($string) {
-	return utf8_to_windows1252($string, "//TRANSLIT");
 }
